Documentation
¶
Index ¶
- Variables
- func AllOfType(subject acktypes.ConditionManager, condType ackv1alpha1.ConditionType) []*ackv1alpha1.Condition
- func Clear(subject acktypes.ConditionManager)
- func FirstOfType(subject acktypes.ConditionManager, condType ackv1alpha1.ConditionType) *ackv1alpha1.Condition
- func LateInitializationInProgress(subject acktypes.ConditionManager) bool
- func LateInitialized(subject acktypes.ConditionManager) *ackv1alpha1.Condition
- func Recoverable(subject acktypes.ConditionManager) *ackv1alpha1.Condition
- func ReferencesResolved(subject acktypes.ConditionManager) *ackv1alpha1.Condition
- func RemoveReferencesResolved(subject acktypes.ConditionManager)
- func SetLateInitialized(subject acktypes.ConditionManager, status corev1.ConditionStatus, ...)
- func SetRecoverable(subject acktypes.ConditionManager, status corev1.ConditionStatus, ...)
- func SetReferencesResolved(subject acktypes.ConditionManager, status corev1.ConditionStatus, ...)
- func SetSynced(subject acktypes.ConditionManager, status corev1.ConditionStatus, ...)
- func SetTerminal(subject acktypes.ConditionManager, status corev1.ConditionStatus, ...)
- func Synced(subject acktypes.ConditionManager) *ackv1alpha1.Condition
- func Terminal(subject acktypes.ConditionManager) *ackv1alpha1.Condition
- func WithReferencesResolvedCondition(resource acktypes.AWSResource, err error) acktypes.AWSResource
Constants ¶
This section is empty.
Variables ¶
var ( NotManagedMessage = "Resource already exists" NotManagedReason = "This resource already exists but is not managed by ACK. " + "To bring the resource under ACK management, you should explicitly adopt " + "the resource by creating a services.k8s.aws/AdoptedResource" UnknownSyncedMessage = "Unable to determine if desired resource state matches latest observed state" NotSyncedMessage = "Resource not synced" SyncedMessage = "Resource synced successfully" FailedReferenceResolutionMessage = "Reference resolution failed" )
Functions ¶
func AllOfType ¶
func AllOfType( subject acktypes.ConditionManager, condType ackv1alpha1.ConditionType, ) []*ackv1alpha1.Condition
AllOfType returns a slice of Conditions in the resource's Conditions collection of the supplied type.
func Clear ¶
func Clear( subject acktypes.ConditionManager, )
Clear resets the resource's collection of Conditions to an empty list.
func FirstOfType ¶
func FirstOfType( subject acktypes.ConditionManager, condType ackv1alpha1.ConditionType, ) *ackv1alpha1.Condition
FirstOfType returns the first Condition in the resource's Conditions collection of the supplied type. If no such condition is found, returns nil.
func LateInitializationInProgress ¶
func LateInitializationInProgress(subject acktypes.ConditionManager) bool
LateInitializationInProgress return true if ConditionTypeLateInitialized has "False" status False status means that resource has LateInitializationConfig but has not been completely late initialized yet.
func LateInitialized ¶
func LateInitialized(subject acktypes.ConditionManager) *ackv1alpha1.Condition
LateInitialized returns the Condition in the resource's Conditions collection that is of type ConditionTypeLateInitialized. If no such condition is found, returns nil.
func Recoverable ¶
func Recoverable(subject acktypes.ConditionManager) *ackv1alpha1.Condition
Recoverable returns the Condition in the resource's Conditions collection that is of type ConditionTypeRecoverable. If no such condition is found, returns nil.
func ReferencesResolved ¶
func ReferencesResolved(subject acktypes.ConditionManager) *ackv1alpha1.Condition
ReferencesResolved returns the Condition in the resource's Conditions collection that is of type ConditionTypeReferencesResolved. If no such condition is found, returns nil.
func RemoveReferencesResolved ¶
func RemoveReferencesResolved( subject acktypes.ConditionManager, )
RemoveReferencesResolved removes the condition of type ConditionTypeReferencesResolved from the resource's conditions
func SetLateInitialized ¶
func SetLateInitialized( subject acktypes.ConditionManager, status corev1.ConditionStatus, message *string, reason *string, )
SetLateInitialized sets the resource's Condition of type ConditionTypeLateInitialized to the supplied status, optional message and reason.
func SetRecoverable ¶
func SetRecoverable( subject acktypes.ConditionManager, status corev1.ConditionStatus, message *string, reason *string, )
SetRecoverable sets the resource's Condition of type ConditionTypeRecoverable to the supplied status, optional message and reason.
func SetReferencesResolved ¶
func SetReferencesResolved( subject acktypes.ConditionManager, status corev1.ConditionStatus, message *string, reason *string, )
SetReferencesResolved sets the resource's Condition of type ConditionTypeReferencesResolved to the supplied status, optional message and reason.
func SetSynced ¶
func SetSynced( subject acktypes.ConditionManager, status corev1.ConditionStatus, message *string, reason *string, )
SetSynced sets the resource's Condition of type ConditionTypeResourceSynced to the supplied status, optional message and reason.
func SetTerminal ¶
func SetTerminal( subject acktypes.ConditionManager, status corev1.ConditionStatus, message *string, reason *string, )
SetTerminal sets the resource's Condition of type ConditionTypeTerminal to the supplied status, optional message and reason.
func Synced ¶
func Synced(subject acktypes.ConditionManager) *ackv1alpha1.Condition
Synced returns the Condition in the resource's Conditions collection that is of type ConditionTypeResourceSynced. If no such condition is found, returns nil.
func Terminal ¶
func Terminal(subject acktypes.ConditionManager) *ackv1alpha1.Condition
Terminal returns the Condition in the resource's Conditions collection that is of type ConditionTypeTerminal. If no such condition is found, returns nil.
func WithReferencesResolvedCondition ¶
func WithReferencesResolvedCondition( resource acktypes.AWSResource, err error, ) acktypes.AWSResource
WithReferencesResolvedCondition returns a new AWSResource with the ConditionTypeReferencesResolved set based on the err parameter
Types ¶
This section is empty.